@@ -72,7 +72,7 @@ class client:
                 self.client_instance.property_list.append(settle)
                 self.client_instance.player.acquireNode(settle)
                 port = self.client_instance.game_board.xy_give_port((settle.cord1, settle.cord2))
-                print(settle.cord1, settle.cord2)
+                #print(settle.cord1, settle.cord2)
                 if port is not None:
                     self.client_instance.player.bankTrading.update(port.resource)
                 self.client_instance.set_board_updated(True)
@@ -91,15 +91,15 @@ class client:
                 ClientSocket.send(str.encode(coordinates + '\n'))
                 ClientSocket.send(str.encode("enemyu," + self.client_instance.player.getSendToEnemies() + '\n'))
             elif Response.split(',')[0] == "set":
-                print("new settlement" + Response.split(',')[1] + Response.split(',')[1])
+                #print("new settlement" + Response.split(',')[1] + Response.split(',')[1])
                 self.client_instance.property_list.append(
                     self.client_instance.building_locations.claimSettlement(int(Response.split(',')[1]),
                                                                             int(Response.split(',')[2]),
                                                                             Response.split(',')[3]))
                 self.client_instance.set_board_updated(True)
             elif Response.split(',')[0] == "road":
-                print("new road")
-                print("new settlement" + Response.split(',')[1] + Response.split(',')[1])
+                #print("new road")
+                #print("new settlement" + Response.split(',')[1] + Response.split(',')[1])
                 self.client_instance.road_list.append(
                     self.client_instance.building_locations.claimRoad(int(Response.split(',')[1]),
                                                                       int(Response.split(',')[2]),
@@ -110,17 +110,17 @@ class client:
                     int(Response.split(',')[2])].city = True
                 self.client_instance.set_board_updated(True)
             elif Response.split(',')[0] == "color":
-                print("hi")
+                #print("hi")
                 Color = Response.split(',')[1]
                 screen_num=Response.split(',')[2]
                 self.client_instance.set_player(Player(player_name, Color, screen_num))
-                print(Color)
+                #print(Color)
             elif Response.split(',')[0] == "bank":
                 arr = [int(x) for x in Response.split(',')[1:]]
                 self.client_instance.bank.update(arr)
                 self.client_instance.set_board_updated(True)
             elif Response.split('|')[0] == "board":
-                print("hello")
+                #print("hello")
                 number_list = [int(elem) for elem in Response.split('|')[1].split(',')]
                 resource_list = Response.split('|')[2].split(',')
                 port_list = Response.split('|')[3].split(',')
@@ -130,7 +130,7 @@ class client:
                 self.client_instance.board_updated = True
                 threading.Thread(target=self.board_thread, args=(board,)).start()
             elif Response == "getstart":
-                print("get starting resources")
+                #print("get starting resources")
                 self.client_instance.start_resources()
                 message = board_input.get()
                 board_input.task_done()
@@ -187,7 +187,7 @@ class client:
                     if (message == "dev"):
                         ClientSocket.send(str.encode(message + '\n'))
                         card = self.read_from_buffer(ClientSocket)
-                        print(card)
+                        #print(card)
                         self.client_instance.get_dev_card(card)
                         self.client_instance.player.developmentHand.add_card(card)
                         if (card == 'victoryPoint'):
@@ -270,7 +270,8 @@ class client:
                 self.client_instance.running = False
                 break
             elif Response != "":
-                print(Response.split(',')[0])
+                #print(Response.split(',')[0])
+                pass
 
         # while True:
         # Input = input('Say Something: ')
@@ -286,7 +287,7 @@ def main():
     port=1233
     name='Zander'
     num_players=2
-    print(sys.argv)
+    #print(sys.argv)
     if(len(sys.argv)==5):
         address=sys.argv[1]
         port=int(sys.argv[2])
@@ -295,12 +296,13 @@ def main():
     client(address, int(port), name, int(num_players))
 
 
-# if __name__ == "__main__":
+#if __name__ == "__main__":
 #     host = '127.0.0.1'
 #     port = 1233
 #     xy = ''
 #     Name = "Name"
 #     players = 2
+#    test = client('127.0.0.1', 1233, 'zander', 2)
 #     host = sys.argv[1]
 #     try:
 #         port = int(sys.argv[2])
