@@ -854,7 +854,6 @@ class Client:
 
         pygame.init()
         pygame.display.set_caption('Client')
-        pygame.mouse.set_cursor(pygame.cursors.arrow)
         os.chdir(os.path.dirname(__file__))
         font_size = 45
         self.font = pygame.font.SysFont('Comic Sans MS', font_size)
@@ -862,9 +861,10 @@ class Client:
         os.environ["DISPLAY"]=screenstring
         os.environ['SDL_VIDEODRIVER'] = 'x11'
         self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
+        cursor = pygame.cursors.arrow
+        pygame.mouse.set_cursor(*cursor)
         # self.game_window = pygame.display.set_mode(RESOLUTION)
-
-        self.manager = pg_g.UIManager(RESOLUTION, os.path.join(os.path.dirname(__file__), '../themes/card_theme.json'))
+        self.manager = pg_g.UIManager(RESOLUTION, '../themes/card_theme.json')
         self.clock = pygame.time.Clock()
 
         # creates settlement polygon
@@ -895,7 +895,7 @@ class Client:
 
         base_path = os.path.dirname(__file__)
         self.object_textures = {
-            'Board': pygame.image.load(os.path.join(base_path, '../assets/gameboard_grid_v4.png'))
+            'Board': pygame.image.load('../assets/gameboard_grid_v4.png')
         }
 
         self.board_center = (
