@@ -145,24 +145,22 @@ class server:
                     message = readfromBuffer(cli2.socket)
                     sendToAllButOne(message, cli2)
                 if (int(dice.split(',')[0]) + int(dice.split(',')[1]) == 7):
-                    print("afjgsadkfjsad")
                     cli.socket.send(str.encode('robber\n'))
                 else:
                     cli.socket.send(str.encode('turn\n'))
                 while True:
                     message = readfromBuffer(cli.socket)
-                    print(message)
+                    #print(message)
                     if (message == "end"):
                         break
                     if (message.split(',')[0] == "winner"):
-                        print(message)
+                        #print(message)
                         break
                     elif (message == "dev"):
                         card = developmentDeck.pop(0)
                         cli.socket.send(str.encode(card + '\n'))
                     else:
                         sendToAllButOne(message, cli)
-                print("here")
                 cli.socket.send(str.encode('notturn\n'))
                 # message=readfromBuffer(cli.socket)
                 # print(message)
@@ -191,9 +189,10 @@ def main():
     
 
 
-# if __name__ == "__main__":
-#     # host = '127.0.0.1'
-#     # port = 1233
+if __name__ == "__main__":
+    host = '127.0.0.1'
+    port = 1233
+    test = server(host, port)
 #     host = sys.argv[1]
 #     port = int(sys.argv[2])
 #     test = server(host, port)
